pub struct AttributeFilter {
pub field: String,
pub op: FilterOp,
pub value: String,
}Expand description
Attribute filter: matches a named field against a value using an operator.
Fields
field: StringThe name of the feature attribute field to filter on.
op: FilterOpThe comparison operator to apply.
value: StringThe value to compare against.
Implementations
Sourceimpl AttributeFilter
impl AttributeFilter
Sourcepub fn matches_json(&self, props: &Map<String, Value>) -> bool
pub fn matches_json(&self, props: &Map<String, Value>) -> bool
Test whether a JSON properties map matches this filter.
Sourcepub fn matches_field_map(&self, props: &HashMap<String, FieldValue>) -> bool
pub fn matches_field_map(&self, props: &HashMap<String, FieldValue>) -> bool
Test whether an oxigeo_core::vector::FieldValue map matches this filter.